[−][src]Enum tremor_script::lexer::Token
A token in the source ( file, byte stream ), to be emitted by the Lexer
The LALRPOP grammar uses these tokens and this custom lexer
as it does not have a facility to ignore special tokens, to
easily disambiguate tokens ( eg: ':' vs '::' vs ':=' ), nor
to inject magic tokens ( bad token ) or support lexical streams
( different token streams drive by users, eg: emit ignorable tokens when
syntax highlighting or error highlighting
Variants
Whitespace(&'input str)Ignorable when parsing, significant when highlighting
a new line
SingleLineComment(&'input str)a singe line comment
DocComment(&'input str)a doc comment
Bad(String)a BAD TOKEN
an ident
the $ sign
a .
null
BoolLiteral(bool)a boolean
IntLiteral(i64)an integer
an float
a test literal
an heredoc
a double quote "
a string literal
the let keywrod
the const keyword
the match keyword
the case keyword
the of keyword
the when keyword
the end keyword
the patch keyword
the insert keyword
the upsert keyword
the update keyword
the erase keyword
the move keyword
the copy keyword
the merge keyword
the drop keyword
the default keyword
the emit keyword
the for keyword
the event keyword
the state keyword
the present keyword
the absent keyword
the fun keyword
the \ backslash
the , comma
the not keyword
bitwise not !
the and keyword
the or keyword
the xor keyword
bitwise and &
bitwise or |
bitwise xor ^
equal =
double equal ==
not equal !=
tilde equal ~=
tilde ~
greater than equal >=
grater than >
lower than equal <=
lower then <
Right bit shift signed >>
Right bit shift unsigned >>>
Left bit shift <<
Add +
Substract -
Multiply *
Divide /
Moduly `%~
Colon :
Double coilon ::
Effector array =>
Semicolon ;
Left Paren (
Right Paren )
Left brace {
Left pattern Bracket %{
Right Brace }
Left Bracket [
Left pattern Bracket %[
Right bracket ]
End of stream token
The select keyword
The from keyword
The where keyword
The with keyword
The order keyword
the group keyword
The by keyword
The having keyword
The into keyword
The create keyword
The tumbling keyword
The sliding keyword
The window keyword
The stream keyword
The operator keyword
The script keyword
The set keyword
The each keyword
The define keyword
The args keyword