[−][src]Module tremor_script::utils
Utility functions
Functions
| hostname | Fetches a hostname with |
| load_event_file | Loats an event file |
| sorsorted_serialize | Serialize a Value in a sorted fashion to allow equality compairison the result |
Utility functions
| hostname | Fetches a hostname with |
| load_event_file | Loats an event file |
| sorsorted_serialize | Serialize a Value in a sorted fashion to allow equality compairison the result |